@@ -78,6 +78,91 @@ class BinanceFuturesPositionInfo(msgspec.Struct, kw_only=True):
     maxQty: str | None = None  # maximum quantity of base asset
 
 
+class BinancePortfolioMarginPositionRisk(msgspec.Struct, kw_only=True):
+    """
+    "entryPrice": "0.00000",
+    "leverage": "10",
+    "markPrice": "6679.50671178",
+    "maxNotionalValue": "20000000",
+    "positionAmt": "0.000",
+    "notional": "0",
+    "symbol": "BTCUSDT",
+    "unRealizedProfit": "0.00000000",
+    "liquidationPrice": "6170.20509059",
+    "positionSide": "BOTH",
+    "updateTime": 1625474304765
+
+    "symbol": "BTCUSD_201225",
+    "positionAmt": "1",
+    "entryPrice": "11707.70000003",
+    "markPrice": "11788.66626667",
+    "unRealizedProfit": "0.00005866",
+    "liquidationPrice": "6170.20509059",
+    "leverage": "125",
+    "positionSide": "LONG",
+    "updateTime": 1627026881327,
+    "maxQty": "50",
+    "notionalValue": "0.00084827"
+    """
+
+    symbol: str
+    markPrice: str
+    entryPrice: str
+    unRealizedProfit: str
+    positionAmt: str
+    positionSide: BinancePositionSide
+    liquidationPrice: str
+    updateTime: int
+    leverage: str
+
+    notional: str | None = None
+    maxNotionalValue: str | None = None
+
+    maxQty: str | None = None
+    notionalValue: str | None = None
+
+
+class BinancePortfolioMarginBalance(msgspec.Struct, kw_only=True):
+    """
+    "asset": "USDT",    // asset name
+    "totalWalletBalance": "122607.35137903", // wallet balance =  cross margin free + cross margin locked + UM wallet balance + CM wallet balance
+    "crossMarginAsset": "92.27530794", // crossMarginAsset = crossMarginFree + crossMarginLocked
+    "crossMarginBorrowed": "10.00000000", // principal of cross margin
+    "crossMarginFree": "100.00000000", // free asset of cross margin
+    "crossMarginInterest": "0.72469206", // interest of cross margin
+    "crossMarginLocked": "3.00000000", //lock asset of cross margin
+    "umWalletBalance": "0.00000000",  // wallet balance of um
+    "umUnrealizedPNL": "23.72469206",     // unrealized profit of um
+    "cmWalletBalance": "23.72469206",       // wallet balance of cm
+    "cmUnrealizedPNL": "",    // unrealized profit of cm
+    "updateTime": 1617939110373,
+    "negativeBalance": "0"
+    """
+
+    asset: str
+    totalWalletBalance: str
+    crossMarginAsset: str
+    crossMarginBorrowed: str
+    crossMarginFree: str
+    crossMarginInterest: str
+    crossMarginLocked: str
+    umWalletBalance: str
+    umUnrealizedPNL: str
+    cmWalletBalance: str
+    cmUnrealizedPNL: str
+    updateTime: int
+    negativeBalance: str
+
+    def parse_to_balance(self) -> Balance:
+        return Balance(
+            asset=self.asset,
+            free=Decimal(self.crossMarginFree)
+            + Decimal(self.umWalletBalance)
+            + Decimal(self.cmWalletBalance),
+            locked=Decimal(self.crossMarginLocked),
+        )
+
+
 class BinanceFuturesAccountInfo(msgspec.Struct, kw_only=True):
     feeTier: int  # account commission tier
     canTrade: bool  # if can trade
@@ -146,77 +231,94 @@ class BinanceSpotAccountInfo(msgspec.Struct, frozen=True):
 
 
 class BinanceSpotOrderUpdateMsg(msgspec.Struct, kw_only=True):
-    e: BinanceUserDataStreamWsEventType
-    E: int  # Event time
-    s: str  # Symbol
-    c: str  # Client order ID
+    C: str | None = None
+    E: int
+    F: str | None = None
+    I: int  # noqa: E741
+    L: str
+    M: bool | None = None
+    N: str | None = None
+    O: int  # noqa: E741
+    P: str
+    Q: str | None = None
     S: BinanceOrderSide
-    o: BinanceOrderType
-    f: BinanceTimeInForce
-    q: str  # Original Quantity
-    p: str  # Original Price
-    P: str  # Stop price
-    F: str  # Iceberg quantity
-    g: int  # Order list ID
-    C: str  # Original client order ID; This is the ID of the order being canceled
-    x: BinanceExecutionType
+    T: int
+    V: str
+    W: int | None = None  # Working Time
     X: BinanceOrderStatus
-    r: str  # Order reject reason; will be an error code
-    i: int  # Order ID
-    l: str  # Order Last Filled Quantity # noqa
-    z: str  # Order Filled Accumulated Quantity
-    L: str  # Last Filled Price
-    n: str | None = None  # Commission, will not push if no commission
-    N: str | None = None  # Commission Asset, will not push if no commission
-    T: int  # Order Trade Time
-    t: int  # Trade ID
-    I: int  # Ignore # noqa
-    w: bool  # Is the order on the book?
-    m: bool  # Is trade the maker side
-    M: bool  # Ignore
-    O: int  # Order creation time # noqa
-    Z: str  # Cumulative quote asset transacted quantity
-    Y: str  # Last quote asset transacted quantity (i.e. lastPrice * lastQty)
-    Q: str  # Quote Order Qty
+    Y: str
+    Z: str
+    c: str
+    e: BinanceUserDataStreamWsEventType
+    f: BinanceTimeInForce
+    g: int
+    i: int
+    l: str  # noqa: E741
+    m: bool
+    n: str | None = None
+    o: BinanceOrderType
+    p: str
+    q: str
+    r: str | None = None
+    s: str
+    t: int
+    v: int | None = None
+    w: bool
+    x: BinanceExecutionType
+    z: str
+
+    A: str | None = None  # Prevented Quantity
+    B: str | None = None  # Last Prevented Quantity
+    D: int | None = None  # trailing time
+    J: int | None = None  # strategy type
+    U: int | None = None  # CounterOrderId
+    d: int | None = None  # trailing Delta
+    j: int | None = None  # strategy id
+    u: int | None = None  # Trade Group id
 
 
 class BinanceFuturesOrderData(msgspec.Struct, kw_only=True):
-    s: str  # Symbol
-    c: str  # Client Order ID
-    S: BinanceOrderSide
-    o: BinanceOrderType
-    f: BinanceTimeInForce
-    q: str  # Original Quantity
-    p: str  # Original Price
-    ap: str  # Average Price
-    sp: str | None = None  # Stop Price. Ignore with TRAILING_STOP_MARKET order
-    x: BinanceExecutionType
-    X: BinanceOrderStatus
-    i: int  # Order ID
-    l: str  # Order Last Filled Quantity # noqa
-    z: str  # Order Filled Accumulated Quantity
     L: str  # Last Filled Price
-    N: str | None = None  # Commission Asset, will not push if no commission
-    n: str | None = None  # Commission, will not push if no commission
-    T: int  # Order Trade Time
-    t: int  # Trade ID
-    b: str  # Bids Notional
-    a: str  # Ask Notional
-    m: bool  # Is trade the maker side
+    N: str  # Commission Asset
     R: bool  # Is reduce only
-    wt: BinanceFuturesWorkingType
-    ot: BinanceOrderType
+    S: BinanceOrderSide
+    T: int  # Order Trade Time
+    V: str  # Order Filled Accumulated Quantity
+    X: BinanceOrderStatus
+    a: str  # Ask Notional
+    ap: str  # Average Price
+    b: str  # Bids Notional
+    c: str  # Client Order ID
+    f: BinanceTimeInForce
+    i: int  # Order ID
+    l: str  # Order Last Filled Quantity # noqa: E741
+    m: bool  # Is trade the maker side
+    n: str  # Commission, will not push if no commission
+    o: BinanceOrderType
+    p: str  # Original Price
     ps: BinancePositionSide
-    cp: bool | None = None  # If Close-All, pushed with conditional order
-    AP: str | None = (
-        None  # Activation Price, only pushed with TRAILING_STOP_MARKET order
-    )
-    cr: str | None = None  # Callback Rate, only pushed with TRAILING_STOP_MARKET order
-    pP: bool  # ignore
-    si: int  # ignore
-    ss: int  # ignore
+    q: str  # Original Quantity
     rp: str  # Realized Profit of the trade
-    gtd: int  # TIF GTD order auto cancel time
+    s: str  # Symbol
+    sp: str  # Stop Price
+    t: int  # Trade ID
+    x: BinanceExecutionType
+    z: str  # Order Filled Accumulated Quantity
+
+    AP: str | None = None  # Activation Price
+    cp: bool | None = None  # If Close-All, pushed with conditional order
+    cr: str | None = None  # Callback Rate
+    gtd: int | None = None  # TIF GTD order auto cancel time
+    ot: BinanceOrderType | None = None
+    pP: bool | None = None  # ignore
+    pm: str | None = None  # Order Margin Type
+    si: int | None = None  # ignore
+    ss: int | None = None  # ignore
+    wt: BinanceFuturesWorkingType | None = None
+    ma: str | None = None  # Order Margin Type
+    st: str | None = (
+        None  #  Strategy type, only pushed with conditional order triggered
+    )
 
 
 class BinanceFuturesOrderUpdateMsg(msgspec.Struct, kw_only=True):
@@ -513,7 +615,7 @@ class BinanceMarketInfo(msgspec.Struct):
     isMarginTradingAllowed: bool = None
     filters: List[Dict[str, Any]] = None
     permissions: List[str] = None
-    permissionSets: List[List[str]] = None
+    permissionSets: List[List[str] | str] = None
     defaultSelfTradePreventionMode: str = None
     allowedSelfTradePreventionModes: List[str] = None
 
@@ -541,7 +643,7 @@ class BinanceFuturesPositionData(msgspec.Struct, kw_only=True):
     s: str
     pa: str  # position amount
     ep: str  # entry price
-    bep: str  # breakeven price
+    bep: str | float  # breakeven price
     cr: str  # (Pre-fee) Accumulated Realized
     up: str  # Unrealized PnL
     mt: str | None = None  # margin type (if isolated position)
@@ -569,7 +671,7 @@ class BinanceFuturesUpdateMsg(msgspec.Struct, kw_only=True):
 class BinanceSpotBalanceData(msgspec.Struct):
     a: str  # asset
     f: str  # free
-    l: str  # locked
+    l: str  # locked # noqa: E741
 
     def parse_to_balance(self) -> Balance:
         return Balance(
@@ -621,6 +723,36 @@ class BinanceResponseKline(msgspec.Struct, array_like=True):
     ignore: str
 
 
+class BinanceIndexResponseKline(msgspec.Struct, array_like=True):
+    """
+    1591256400000,      	// Open time
+    "9653.69440000",    	// Open
+    "9653.69640000",     	// High
+    "9651.38600000",     	// Low
+    "9651.55200000",     	// Close (or latest price)
+    "0	", 					// Ignore
+    1591256459999,      	// Close time
+    "0",    				// Ignore
+    60,                		// Ignore
+    "0",    				// Ignore
+    "0",      				// Ignore
+    "0" 					// Ignore
+    """
+
+    open_time: int
+    open: str
+    high: str
+    low: str
+    close: str
+    ignore_1: str
+    close_time: int
+    ignore_2: str
+    ignore_3: int
+    ignore_4: str
+    ignore_5: str
+    ignore_6: str
+
+
 class BinanceSpotOrderBookMsg(msgspec.Struct):
     """
     WebSocket message for 'Binance Spot/Margin' Partial Book Depth Streams.
@@ -699,3 +831,135 @@ class BinanceFundingRateResponse(msgspec.Struct, frozen=True):
     fundingRate: str
     fundingTime: int
     markPrice: str | None = None
+
+
+class BinanceBatchOrderResponse(msgspec.Struct, frozen=True, omit_defaults=True):
+    clientOrderId: str | None = None
+    cumQty: str | None = None
+    executedQty: str | None = None
+    orderId: int | None = None
+    avgPrice: str | None = None
+    origQty: str | None = None
+    price: str | None = None
+    reduceOnly: bool | None = None
+    side: BinanceOrderSide | None = None
+    positionSide: BinancePositionSide | None = None
+    status: BinanceOrderStatus | None = None
+    stopPrice: str | None = None
+    closePosition: bool | None = None
+    symbol: str | None = None
+    timeInForce: BinanceTimeInForce | None = None
+    type: BinanceOrderType | None = None
+    origType: BinanceOrderType | None = None
+    updateTime: int | None = None
+    priceProtect: bool | None = None
+    # USD-M specific fields
+    cumQuote: str | None = None
+    goodTillDate: int | None = None
+    # Coin-M specific fields
+    cumBase: str | None = None
+    pair: str | None = None
+    # Optional fields for both
+    activatePrice: str | None = None
+    priceRate: str | None = None
+    workingType: BinanceFuturesWorkingType | None = None
+    priceMatch: BinancePriceMatch | None = None
+    selfTradePreventionMode: str | None = None
+    code: int | None = None
+    msg: str | None = None
+
+
+################################################################################
+# GET /fapi/v1/ticker/24hr and GET /dapi/v1/ticker/24hr
+################################################################################
+
+
+class BinanceFuture24hrTicker(msgspec.Struct):
+    """
+    24hr ticker data structure for Binance Futures (FAPI and DAPI).
+    Supports both USD-M and Coin-M futures.
+    """
+
+    symbol: str  # Symbol name
+    priceChange: str  # Price change
+    priceChangePercent: str  # Price change percentage
+    weightedAvgPrice: str  # Weighted average price
+    lastPrice: str  # Last price
+    lastQty: str  # Last quantity
+    openPrice: str  # Open price
+    highPrice: str  # High price
+    lowPrice: str  # Low price
+    volume: str  # Volume
+    openTime: int  # Open time
+    closeTime: int  # Close time
+    firstId: int  # First trade ID
+    lastId: int  # Last trade ID
+    count: int  # Trade count
+
+    # FAPI specific fields
+    quoteVolume: str | None = None  # Quote volume (FAPI only)
+
+    # DAPI specific fields
+    pair: str | None = None  # Pair name (DAPI only)
+    baseVolume: str | None = None  # Base volume (DAPI only)
+
+
+class BinanceSpot24hrTicker(msgspec.Struct):
+    """
+    24hr ticker data structure for Binance Spot.
+    Supports both FULL and MINI response types.
+    """
+
+    symbol: str  # Symbol name
+    openPrice: str  # Opening price
+    highPrice: str  # Highest price
+    lowPrice: str  # Lowest price
+    lastPrice: str  # Last price
+    volume: str  # Total trade volume (base asset)
+    quoteVolume: str  # Total trade volume (quote asset)
+    openTime: int  # Start of ticker interval
+    closeTime: int  # End of ticker interval
+    firstId: int  # First trade ID
+    lastId: int  # Last trade ID
+    count: int  # Total trade count
+
+    # FULL response additional fields
+    priceChange: str | None = None  # Price change
+    priceChangePercent: str | None = None  # Price change percentage
+    weightedAvgPrice: str | None = None  # Weighted average price
+    prevClosePrice: str | None = None  # Previous close price
+    lastQty: str | None = None  # Last quantity
+    bidPrice: str | None = None  # Best bid price
+    bidQty: str | None = None  # Best bid quantity
+    askPrice: str | None = None  # Best ask price
+    askQty: str | None = None  # Best ask quantity
+
+
+class BinanceWsOrderResponseResult(msgspec.Struct, frozen=True):
+    orderId: int
+    symbol: str
+    clientOrderId: str
+
+
+class BinanceWsOrderResponseError(msgspec.Struct, frozen=True):
+    code: int
+    msg: str
+
+    @property
+    def format_str(self) -> str:
+        return f"code={self.code} error={self.msg}"
+
+
+class BinanceWsOrderResponse(msgspec.Struct, frozen=True):
+    id: str
+    status: int
+    result: BinanceWsOrderResponseResult | None = None
+    error: BinanceWsOrderResponseError | None = None
+
+    @property
+    def is_success(self) -> bool:
+        return self.status == 200
+
+    @property
+    def is_failed(self) -> bool:
+        return self.status != 200
