@@ -1,17 +1,14 @@
 import msgspec
-import sys
 from typing import Dict, List
-from decimal import Decimal
 from collections import defaultdict
 from nexustrader.base import PublicConnector, PrivateConnector
-from nexustrader.core.nautilius_core import MessageBus
-from nexustrader.core.entity import TaskManager, RateLimit
+from nexustrader.core.nautilius_core import MessageBus, LiveClock
+from nexustrader.core.entity import TaskManager
+from nexustrader.core.registry import OrderRegistry
 from nexustrader.core.cache import AsyncCache
 from nexustrader.schema import (
     BookL1,
-    Order,
     Trade,
-    Position,
     Kline,
     BookL2,
     BookOrderData,
@@ -19,36 +16,29 @@ from nexustrader.schema import (
     IndexPrice,
     MarkPrice,
     KlineList,
+    Ticker,
 )
 from nexustrader.constants import (
-    OrderSide,
-    OrderStatus,
-    OrderType,
-    TimeInForce,
-    PositionSide,
     KlineInterval,
-    TriggerType,
     BookLevel,
 )
 from nexustrader.exchange.bybit.schema import (
     BybitKlineResponse,
     BybitKlineResponseArray,
     BybitWsMessageGeneral,
-    BybitWsOrderMsg,
     BybitWsOrderbookDepthMsg,
     BybitOrderBook,
     BybitMarket,
     BybitWsTradeMsg,
-    BybitWsPositionMsg,
     BybitWsTickerMsg,
-    BybitWsAccountWalletMsg,
     BybitWsKlineMsg,
-    BybitWalletBalanceResponse,
-    BybitPositionResponse,
     BybitTicker,
+    BybitIndexKlineResponse,
+    BybitIndexKlineResponseArray,
 )
 from nexustrader.exchange.bybit.rest_api import BybitApiClient
 from nexustrader.exchange.bybit.websockets import BybitWSClient
+from nexustrader.exchange.bybit.oms import BybitOrderManagementSystem
 from nexustrader.exchange.bybit.constants import (
     BybitAccountType,
     BybitEnumParser,
@@ -66,9 +56,10 @@ class BybitPublicConnector(PublicConnector):
         account_type: BybitAccountType,
         exchange: BybitExchangeManager,
         msgbus: MessageBus,
+        clock: LiveClock,
         task_manager: TaskManager,
-        rate_limit: RateLimit | None = None,
         custom_url: str | None = None,
+        enable_rate_limit: bool = True,
     ):
         if account_type in {BybitAccountType.UNIFIED, BybitAccountType.UNIFIED_TESTNET}:
             raise ValueError(
@@ -83,15 +74,18 @@ class BybitPublicConnector(PublicConnector):
             ws_client=BybitWSClient(
                 account_type=account_type,
                 handler=self._ws_msg_handler,
+                clock=clock,
                 task_manager=task_manager,
                 custom_url=custom_url,
             ),
+            clock=clock,
             msgbus=msgbus,
             api_client=BybitApiClient(
+                clock=clock,
                 testnet=account_type.is_testnet,
+                enable_rate_limit=enable_rate_limit,
             ),
             task_manager=task_manager,
-            rate_limit=rate_limit,
         )
         self._ws_msg_trade_decoder = msgspec.json.Decoder(BybitWsTradeMsg)
         self._ws_msg_orderbook_decoder = msgspec.json.Decoder(BybitWsOrderbookDepthMsg)
@@ -157,7 +151,7 @@ class BybitPublicConnector(PublicConnector):
         funding_rate = FundingRate(
             exchange=self._exchange_id,
             symbol=symbol,
-            rate=ticker.fundingRate,
+            rate=float(ticker.fundingRate),
             timestamp=msg.ts,
             next_funding_time=int(ticker.nextFundingTime),
         )
@@ -257,25 +251,59 @@ class BybitPublicConnector(PublicConnector):
         )
         self._msgbus.publish(topic="bookl2", msg=bookl2)
 
-    def request_klines(
+    def request_ticker(
         self,
         symbol: str,
-        interval: KlineInterval,
-        limit: int | None = None,
-        start_time: int | None = None,
-        end_time: int | None = None,
-    ) -> list[Kline]:
-        return self._task_manager.run_sync(
-            self._request_klines(
-                symbol=symbol,
-                interval=interval,
-                limit=limit,
-                start_time=start_time,
-                end_time=end_time,
-            )
+    ) -> Ticker:
+        """Request 24hr ticker data"""
+        market = self._market.get(symbol)
+        if not market:
+            raise ValueError(f"Symbol {symbol} formated wrongly, or not supported")
+        category = self._get_category(market)
+        id = market.id
+        ticker_response = self._api_client.get_v5_market_tickers(
+            category=category, symbol=id
         )
+        for ticker in ticker_response.result.list:
+            return Ticker(
+                exchange=self._exchange_id,
+                symbol=symbol,
+                last_price=float(ticker.lastPrice),
+                timestamp=ticker_response.time,
+                volume=float(ticker.volume24h),
+                volumeCcy=float(ticker.turnover24h),
+            )
 
-    async def _request_klines(
+    def request_all_tickers(
+        self,
+    ) -> Dict[str, Ticker]:
+        """Request 24hr ticker data for multiple symbols"""
+        if self._account_type.is_spot:
+            category = "spot"
+        elif self._account_type.is_linear:
+            category = "linear"
+        elif self._account_type.is_inverse:
+            category = "inverse"
+        ticker_response = self._api_client.get_v5_market_tickers(
+            category=category,
+        )
+        tickers = {}
+        for ticker in ticker_response.result.list:
+            id = ticker.symbol + self.market_type
+            symbol = self._market_id.get(id)
+            if not symbol:
+                continue
+            tickers[symbol] = Ticker(
+                exchange=self._exchange_id,
+                symbol=symbol,
+                last_price=float(ticker.lastPrice),
+                timestamp=ticker_response.time,
+                volume=float(ticker.volume24h),
+                volumeCcy=float(ticker.turnover24h),
+            )
+        return tickers
+
+    def request_index_klines(
         self,
         symbol: str,
         interval: KlineInterval,
@@ -283,9 +311,90 @@ class BybitPublicConnector(PublicConnector):
         start_time: int | None = None,
         end_time: int | None = None,
     ) -> KlineList:
-        if self._limiter:
-            await self._limiter.acquire()
+        market = self._market.get(symbol)
+        if not market:
+            raise ValueError(f"Symbol {symbol} formated wrongly, or not supported")
+        if market.spot:
+            raise ValueError("Spot market is not supported for index klines")
+        category = self._get_category(market)
+        id = market.id
+        bybit_interval = BybitEnumParser.to_bybit_kline_interval(interval)
+        all_klines: list[Kline] = []
+        seen_timestamps: set[int] = set()
+        prev_start_time: int | None = None
 
+        while True:
+            # Check for infinite loop condition
+            if prev_start_time is not None and prev_start_time == start_time:
+                break
+            prev_start_time = start_time
+
+            klines_response: BybitIndexKlineResponse = (
+                self._api_client.get_v5_market_index_price_kline(
+                    category=category,
+                    symbol=id,
+                    interval=bybit_interval.value,
+                    limit=1000,
+                    start=start_time,
+                    end=end_time,
+                )
+            )
+
+            # Sort klines by start time and filter out duplicates
+            response_klines = sorted(
+                klines_response.result.list, key=lambda k: int(k.startTime)
+            )
+            klines: list[Kline] = [
+                self._handle_index_candlesticks(
+                    symbol=symbol,
+                    interval=interval,
+                    kline=kline,
+                    timestamp=klines_response.time,
+                )
+                for kline in response_klines
+                if int(kline.startTime) not in seen_timestamps
+            ]
+
+            all_klines.extend(klines)
+            seen_timestamps.update(int(kline.startTime) for kline in response_klines)
+
+            # If no new klines were found, break
+            if not klines:
+                break
+
+            # Update the start_time to fetch the next set of bars
+            start_time = int(response_klines[-1].startTime) + 1
+
+            # No more bars to fetch if we've reached the end time
+            if end_time is not None and start_time >= end_time:
+                break
+
+        # If limit is specified, return the last 'limit' number of klines
+        if limit is not None and len(all_klines) > limit:
+            all_klines = all_klines[-limit:]
+
+        kline_list = KlineList(
+            all_klines,
+            fields=[
+                "timestamp",
+                "symbol",
+                "open",
+                "high",
+                "low",
+                "close",
+                "confirm",
+            ],
+        )
+        return kline_list
+
+    def request_klines(
+        self,
+        symbol: str,
+        interval: KlineInterval,
+        limit: int | None = None,
+        start_time: int | None = None,
+        end_time: int | None = None,
+    ) -> KlineList:
         market = self._market.get(symbol)
         if not market:
             raise ValueError(f"Symbol {symbol} formated wrongly, or not supported")
@@ -302,15 +411,13 @@ class BybitPublicConnector(PublicConnector):
                 break
             prev_start_time = start_time
 
-            klines_response: BybitKlineResponse = (
-                await self._api_client.get_v5_market_kline(
-                    category=category,
-                    symbol=id,
-                    interval=bybit_interval.value,
-                    limit=1000,
-                    start=start_time,
-                    end=end_time,
-                )
+            klines_response: BybitKlineResponse = self._api_client.get_v5_market_kline(
+                category=category,
+                symbol=id,
+                interval=bybit_interval.value,
+                limit=1000,
+                start=start_time,
+                end=end_time,
             )
 
             # Sort klines by start time and filter out duplicates
@@ -457,6 +564,32 @@ class BybitPublicConnector(PublicConnector):
 
         await self._ws_client.subscribe_order_book(symbols, depth=50)
 
+    def _handle_index_candlesticks(
+        self,
+        symbol: str,
+        interval: KlineInterval,
+        kline: BybitIndexKlineResponseArray,
+        timestamp: int,
+    ) -> Kline:
+        local_timestamp = self._clock.timestamp_ms()
+        confirm = (
+            True
+            if local_timestamp >= int(kline.startTime) + interval.seconds * 1000 - 1
+            else False
+        )
+        return Kline(
+            exchange=self._exchange_id,
+            symbol=symbol,
+            interval=interval,
+            open=float(kline.openPrice),
+            high=float(kline.highPrice),
+            low=float(kline.lowPrice),
+            close=float(kline.closePrice),
+            start=int(kline.startTime),
+            timestamp=timestamp,
+            confirm=confirm,
+        )
+
     def _handle_candlesticks(
         self,
         symbol: str,
@@ -487,24 +620,24 @@ class BybitPublicConnector(PublicConnector):
 
 
 class BybitPrivateConnector(PrivateConnector):
-    _ws_client: BybitWSClient
     _account_type: BybitAccountType
     _market: Dict[str, BybitMarket]
     _market_id: Dict[str, str]
     _api_client: BybitApiClient
+    _oms: BybitOrderManagementSystem
 
     def __init__(
         self,
-        exchange: BybitExchangeManager,
         account_type: BybitAccountType,
+        exchange: BybitExchangeManager,
         cache: AsyncCache,
+        registry: OrderRegistry,
+        clock: LiveClock,
         msgbus: MessageBus,
         task_manager: TaskManager,
-        rate_limit: RateLimit | None = None,
+        enable_rate_limit: bool = True,
+        **kwargs,
     ):
-        # all the private endpoints are the same for all account types, so no need to pass account_type
-        # only need to determine if it's testnet or not
-
         if not exchange.api_key or not exchange.secret:
             raise ValueError("API key and secret are required for private endpoints")
 
@@ -516,455 +649,41 @@ class BybitPrivateConnector(PrivateConnector):
                 "Please using `BybitAccountType.UNIFIED` or `BybitAccountType.UNIFIED_TESTNET` in `PrivateConnector`"
             )
 
+        api_client = BybitApiClient(
+            clock=clock,
+            api_key=exchange.api_key,
+            secret=exchange.secret,
+            testnet=account_type.is_testnet,
+            enable_rate_limit=enable_rate_limit,
+            **kwargs,
+        )
+
+        oms = BybitOrderManagementSystem(
+            account_type=account_type,
+            api_key=exchange.api_key,
+            secret=exchange.secret,
+            market=exchange.market,
+            market_id=exchange.market_id,
+            registry=registry,
+            cache=cache,
+            api_client=api_client,
+            exchange_id=exchange.exchange_id,
+            clock=clock,
+            msgbus=msgbus,
+            task_manager=task_manager,
+            enable_rate_limit=enable_rate_limit,
+        )
+
         super().__init__(
             account_type=account_type,
             market=exchange.market,
-            market_id=exchange.market_id,
-            exchange_id=exchange.exchange_id,
-            ws_client=BybitWSClient(
-                account_type=account_type,
-                handler=self._ws_msg_handler,
-                task_manager=task_manager,
-                api_key=exchange.api_key,
-                secret=exchange.secret,
-            ),
-            api_client=BybitApiClient(
-                api_key=exchange.api_key,
-                secret=exchange.secret,
-                testnet=account_type.is_testnet,
-            ),
-            msgbus=msgbus,
-            cache=cache,
-            rate_limit=rate_limit,
+            api_client=api_client,
             task_manager=task_manager,
+            oms=oms,
         )
 
-        self._ws_msg_general_decoder = msgspec.json.Decoder(BybitWsMessageGeneral)
-        self._ws_msg_order_update_decoder = msgspec.json.Decoder(BybitWsOrderMsg)
-        self._ws_msg_position_decoder = msgspec.json.Decoder(BybitWsPositionMsg)
-        self._ws_msg_wallet_decoder = msgspec.json.Decoder(BybitWsAccountWalletMsg)
-
     async def connect(self):
-        await super().connect()
-        await self._ws_client.subscribe_order()
-        await self._ws_client.subscribe_position()
-        await self._ws_client.subscribe_wallet()
-
-    def _ws_msg_handler(self, raw: bytes):
-        try:
-            ws_msg = self._ws_msg_general_decoder.decode(raw)
-            if ws_msg.op == "pong":
-                self._ws_client._transport.notify_user_specific_pong_received()
-                self._log.debug(f"Pong received {str(ws_msg)}")
-                return
-            if ws_msg.success is False:
-                self._log.error(f"WebSocket error: {ws_msg}")
-                return
-            if "order" in ws_msg.topic:
-                self._parse_order_update(raw)
-            elif "position" in ws_msg.topic:
-                self._parse_position_update(raw)
-            elif "wallet" == ws_msg.topic:
-                self._parse_wallet_update(raw)
-        except msgspec.DecodeError as e:
-            self._log.error(f"Error decoding message: {str(raw)} {e}")
-
-    def _get_category(self, market: BybitMarket):
-        if market.spot:
-            return "spot"
-        elif market.linear:
-            return "linear"
-        elif market.inverse:
-            return "inverse"
-        else:
-            raise ValueError(f"Unsupported market type: {market.type}")
-
-    async def cancel_order(self, symbol: str, order_id: str, **kwargs):
-        if self._limiter:
-            await self._limiter.acquire()
-        try:
-            market = self._market.get(symbol)
-            if not market:
-                raise ValueError(f"Symbol {symbol} formated wrongly, or not supported")
-            symbol = market.id
-
-            category = self._get_category(market)
-
-            params = {
-                "category": category,
-                "symbol": symbol,
-                "order_id": order_id,
-                **kwargs,
-            }
-
-            res = await self._api_client.post_v5_order_cancel(**params)
-            order = Order(
-                exchange=self._exchange_id,
-                id=res.result.orderId,
-                client_order_id=res.result.orderLinkId,
-                timestamp=res.time,
-                symbol=market.symbol,
-                status=OrderStatus.CANCELING,
-            )
-            return order
-        except Exception as e:
-            error_msg = f"{type(e).__name__}: {str(e)}"
-            self._log.error(f"Error canceling order: {error_msg} params: {str(params)}")
-            order = Order(
-                exchange=self._exchange_id,
-                timestamp=self._clock.timestamp_ms(),
-                symbol=symbol,
-                status=OrderStatus.CANCEL_FAILED,
-            )
-            return order
-
-    async def _init_account_balance(self):
-        res: BybitWalletBalanceResponse = (
-            await self._api_client.get_v5_account_wallet_balance(account_type="UNIFIED")
-        )
-        for result in res.result.list:
-            self._cache._apply_balance(self._account_type, result.parse_to_balances())
-
-    async def _init_position(self):
-        res_linear: BybitPositionResponse = await self._api_client.get_v5_position_list(
-            category="linear", settleCoin="USDT", limit=200
-        )  # TODO: position must be smaller than 200
-        res_inverse: BybitPositionResponse = (
-            await self._api_client.get_v5_position_list(category="inverse", limit=200)
-        )
-
-        cache_positions = self._cache.get_all_positions(self._exchange_id)
-
-        self._apply_cache_position(res_linear, cache_positions)
-        self._apply_cache_position(res_inverse, cache_positions)
-
-        for symbol, position in cache_positions.items():
-            position = Position(
-                symbol=symbol,
-                exchange=self._exchange_id,
-                side=None,
-                signed_amount=Decimal(0),
-                entry_price=0,
-                unrealized_pnl=0,
-                realized_pnl=0,
-            )
-            self._cache._apply_position(position)
-
-    def _apply_cache_position(
-        self, res: BybitPositionResponse, cache_positions: Dict[str, Position]
-    ):
-        category = res.result.category
-        for result in res.result.list:
-            side = result.side.parse_to_position_side()
-            if side == PositionSide.FLAT:
-                signed_amount = Decimal(0)
-                side = None
-            elif side == PositionSide.LONG:
-                signed_amount = Decimal(result.size)
-            elif side == PositionSide.SHORT:
-                signed_amount = -Decimal(result.size)
-
-            if category.is_inverse:
-                id = result.symbol + "_inverse"
-            elif category.is_linear:
-                id = result.symbol + "_linear"
-
-            symbol = self._market_id[id]
-
-            cache_positions.pop(symbol, None)
-
-            position = Position(
-                symbol=symbol,
-                exchange=self._exchange_id,
-                side=side,
-                signed_amount=signed_amount,
-                entry_price=float(result.avgPrice),
-                unrealized_pnl=float(result.unrealisedPnl),
-                realized_pnl=float(result.cumRealisedPnl),
-            )
-            self._cache._apply_position(position)
-
-    async def create_stop_loss_order(
-        self,
-        symbol: str,
-        side: OrderSide,
-        type: OrderType,
-        amount: Decimal,
-        trigger_price: Decimal,
-        trigger_type: TriggerType = TriggerType.LAST_PRICE,
-        price: Decimal | None = None,
-        time_in_force: TimeInForce = TimeInForce.GTC,
-        position_side: PositionSide | None = None,
-        **kwargs,
-    ) -> Order:
-        # TODO: implement
-        pass
-
-    async def create_take_profit_order(
-        self,
-        symbol: str,
-        side: OrderSide,
-        type: OrderType,
-        amount: Decimal,
-        trigger_price: Decimal,
-        trigger_type: TriggerType = TriggerType.LAST_PRICE,
-        price: Decimal | None = None,
-        time_in_force: TimeInForce = TimeInForce.GTC,
-        position_side: PositionSide | None = None,
-        **kwargs,
-    ) -> Order:
-        # TODO: implement
-        pass
-
-    async def create_order(
-        self,
-        symbol: str,
-        side: OrderSide,
-        type: OrderType,
-        amount: Decimal,
-        price: Decimal | None = None,
-        time_in_force: TimeInForce = TimeInForce.GTC,
-        position_side: PositionSide | None = None,
-        **kwargs,
-    ):
-        if self._limiter:
-            await self._limiter.acquire()
-        market = self._market.get(symbol)
-        if not market:
-            raise ValueError(f"Symbol {symbol} formated wrongly, or not supported")
-        symbol = market.id
-
-        category = self._get_category(market)
-
-        params = {
-            "category": category,
-            "symbol": symbol,
-            "order_type": BybitEnumParser.to_bybit_order_type(type).value,
-            "side": BybitEnumParser.to_bybit_order_side(side).value,
-            "qty": str(amount),
-        }
-
-        if type == OrderType.LIMIT:
-            if not price:
-                raise ValueError("Price is required for limit order")
-            params["price"] = str(price)
-            params["timeInForce"] = BybitEnumParser.to_bybit_time_in_force(
-                time_in_force
-            ).value
-
-        if position_side:
-            params["positionSide"] = BybitEnumParser.to_bybit_position_side(
-                position_side
-            ).value
-
-        reduce_only = kwargs.pop("reduceOnly", False) or kwargs.pop(
-            "reduce_only", False
-        )
-        if reduce_only:
-            params["reduceOnly"] = True
-        params.update(kwargs)
-
-        try:
-            res = await self._api_client.post_v5_order_create(**params)
-
-            order = Order(
-                exchange=self._exchange_id,
-                id=res.result.orderId,
-                client_order_id=res.result.orderLinkId,
-                timestamp=int(res.time),
-                symbol=market.symbol,
-                type=type,
-                side=side,
-                amount=amount,
-                price=float(price) if price else None,
-                time_in_force=time_in_force,
-                position_side=position_side,
-                status=OrderStatus.PENDING,
-                filled=Decimal(0),
-                remaining=amount,
-                reduce_only=reduce_only,
-            )
-            return order
-        except Exception as e:
-            error_msg = f"{e.__class__.__name__}: {str(e)}"
-            self._log.error(f"Error creating order: {error_msg} params: {str(params)}")
-            order = Order(
-                exchange=self._exchange_id,
-                timestamp=self._clock.timestamp_ms(),
-                symbol=symbol,
-                type=type,
-                side=side,
-                amount=amount,
-                price=float(price) if price else None,
-                time_in_force=time_in_force,
-                position_side=position_side,
-                status=OrderStatus.FAILED,
-                filled=Decimal(0),
-                remaining=amount,
-            )
-            return order
-
-    async def cancel_all_orders(self, symbol: str) -> bool:
-        if self._limiter:
-            await self._limiter.acquire()
-        try:
-            market = self._market.get(symbol)
-            if not market:
-                raise ValueError(f"Symbol {symbol} formated wrongly, or not supported")
-            symbol = market.id
-
-            category = self._get_category(market)
-
-            params = {
-                "category": category,
-                "symbol": symbol,
-            }
-
-            await self._api_client.post_v5_order_cancel_all(**params)
-            return True
-        except Exception as e:
-            error_msg = f"{e.__class__.__name__}: {str(e)}"
-            self._log.error(
-                f"Error canceling all orders: {error_msg} params: {str(params)}"
-            )
-            return False
-
-    async def modify_order(
-        self,
-        symbol: str,
-        order_id: str,
-        side: OrderSide | None = None,
-        price: Decimal | None = None,
-        amount: Decimal | None = None,
-        **kwargs,
-    ):
-        # NOTE: side is not supported for modify order
-        if self._limiter:
-            await self._limiter.acquire()
-        market = self._market.get(symbol)
-        if not market:
-            raise ValueError(f"Symbol {symbol} formated wrongly, or not supported")
-        symbol = market.id
-
-        category = self._get_category(market)
-        params = {
-            "category": category,
-            "symbol": symbol,
-            "orderId": order_id,
-            "price": str(price) if price else None,
-            "qty": str(amount) if amount else None,
-            **kwargs,
-        }
-
-        try:
-            res = await self._api_client.post_v5_order_amend(**params)
-            order = Order(
-                exchange=self._exchange_id,
-                id=res.result.orderId,
-                client_order_id=res.result.orderLinkId,
-                timestamp=int(res.time),
-                symbol=market.symbol,
-                status=OrderStatus.PENDING,
-                filled=Decimal(0),
-                price=float(price) if price else None,
-                remaining=amount,
-            )
-            return order
-        except Exception as e:
-            error_msg = f"{e.__class__.__name__}: {str(e)}"
-            self._log.error(f"Error modifying order: {error_msg} params: {str(params)}")
-            order = Order(
-                exchange=self._exchange_id,
-                timestamp=self._clock.timestamp_ms(),
-                symbol=symbol,
-                status=OrderStatus.FAILED,
-                filled=Decimal(0),
-                remaining=amount,
-                price=float(price) if price else None,
-            )
-            return order
-
-    def _parse_order_update(self, raw: bytes):
-        order_msg = self._ws_msg_order_update_decoder.decode(raw)
-        self._log.debug(f"Order update: {str(order_msg)}")
-        for data in order_msg.data:
-            category = data.category
-            if category.is_spot:
-                id = data.symbol + "_spot"
-            elif category.is_linear:
-                id = data.symbol + "_linear"
-            elif category.is_inverse:
-                id = data.symbol + "_inverse"
-            symbol = self._market_id[id]
-
-            order = Order(
-                exchange=self._exchange_id,
-                symbol=symbol,
-                status=BybitEnumParser.parse_order_status(data.orderStatus),
-                id=data.orderId,
-                client_order_id=data.orderLinkId,
-                timestamp=int(data.updatedTime),
-                type=BybitEnumParser.parse_order_type(data.orderType),
-                side=BybitEnumParser.parse_order_side(data.side),
-                time_in_force=BybitEnumParser.parse_time_in_force(data.timeInForce),
-                price=float(data.price),
-                average=float(data.avgPrice) if data.avgPrice else None,
-                amount=Decimal(data.qty),
-                filled=Decimal(data.cumExecQty),
-                remaining=Decimal(data.qty)
-                - Decimal(
-                    data.cumExecQty
-                ),  # TODO: check if this is correct leavsQty is not correct
-                fee=Decimal(data.cumExecFee),
-                fee_currency=data.feeCurrency,
-                cum_cost=Decimal(data.cumExecValue),
-                reduce_only=data.reduceOnly,
-                position_side=BybitEnumParser.parse_position_side(data.positionIdx),
-            )
-
-            self._msgbus.send(endpoint="bybit.order", msg=order)
-
-    def _parse_position_update(self, raw: bytes):
-        position_msg = self._ws_msg_position_decoder.decode(raw)
-        self._log.debug(f"Position update: {str(position_msg)}")
-
-        for data in position_msg.data:
-            category = data.category
-            if category.is_linear:  # only linear/inverse/ position is supported
-                id = data.symbol + "_linear"
-            elif category.is_inverse:
-                id = data.symbol + "_inverse"
-            symbol = self._market_id[id]
-
-            side = data.side.parse_to_position_side()
-            if side == PositionSide.LONG:
-                signed_amount = Decimal(data.size)
-            elif side == PositionSide.SHORT:
-                signed_amount = -Decimal(data.size)
-            else:
-                side = None
-                signed_amount = Decimal(0)
-
-            position = Position(
-                symbol=symbol,
-                exchange=self._exchange_id,
-                side=side,
-                signed_amount=signed_amount,
-                entry_price=float(data.entryPrice),
-                unrealized_pnl=float(data.unrealisedPnl),
-                realized_pnl=float(data.cumRealisedPnl),
-            )
-
-            self._cache._apply_position(position)
-
-    def _parse_wallet_update(self, raw: bytes):
-        wallet_msg = self._ws_msg_wallet_decoder.decode(raw)
-        self._log.debug(f"Wallet update: {str(wallet_msg)}")
-
-        for data in wallet_msg.data:
-            balances = data.parse_to_balances()
-            self._cache._apply_balance(self._account_type, balances)
-
-    async def disconnect(self):
-        await super().disconnect()
-        await self._api_client.close_session()
+        await self._oms._ws_api_client.connect()
+        await self._oms._ws_client.subscribe_order()
+        await self._oms._ws_client.subscribe_position()
+        await self._oms._ws_client.subscribe_wallet()
